"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var fs_1 = tslib_1.__importDefault(require("fs"));
var path_1 = tslib_1.__importDefault(require("path"));
var assets;
var assetsLoaded = false;
exports.getAssetsFile = function (base) { return path_1.default.resolve(base, 'assets.json'); };
var ensureAssets = function (runtimeConfig) {
    if (assetsLoaded) {
        return;
    }
    var assetsFile = exports.getAssetsFile(runtimeConfig.BASE);
    try {
        var assetsFileContents = fs_1.default.readFileSync(assetsFile);
        assets = JSON.parse(assetsFileContents.toString());
        assetsLoaded = true;
    }
    catch (e) {
        throw new Error("Cannot read assets file from " + assetsFile);
    }
};
exports.setDefaultAssets = function (buildConfig) {
    // When running in dev mode, we don't use assets.json so we need to prime
    // the assets location
    updateAssetLocations({
        main: {
            css: buildConfig.PUBLIC_PATH + buildConfig.ASSETS_PATH_PREFIX + 'css/main.css',
            js: buildConfig.PUBLIC_PATH + buildConfig.ASSETS_PATH_PREFIX + 'js/main.js',
        },
    });
};
function updateAssetLocations(newAssets) {
    assets = newAssets;
    assetsLoaded = true;
}
exports.updateAssetLocations = updateAssetLocations;
function getAssetLocations(runtimeConfig) {
    ensureAssets(runtimeConfig);
    return assets;
}
exports.getAssetLocations = getAssetLocations;
function getAssets(runtimeConfig) {
    ensureAssets(runtimeConfig);
    return assets;
}
exports.getAssets = getAssets;
exports.getAbsoluteAssetPath = function (runtimeConfig, asset) {
    var staticPath = runtimeConfig.PUBLIC_PATH + runtimeConfig.ASSETS_PATH_PREFIX;
    var relativeAsset = asset.slice(staticPath.length);
    if (relativeAsset[0] === '/') {
        relativeAsset = relativeAsset.slice(1);
    }
    return path_1.default.resolve(runtimeConfig.ASSETS_PATH, relativeAsset);
};
function getHeadAssets(buildAssets) {
    return Object.keys(buildAssets)
        .filter(function (chunkName) {
        var chunk = buildAssets[chunkName];
        return chunk.css;
    })
        .map(function (chunkName) { return ({
        tag: "<link id=\"css-main\" type=\"text/css\" rel=\"stylesheet\" href=\"" + buildAssets[chunkName].css + "\">",
    }); });
}
exports.getHeadAssets = getHeadAssets;
function getBodyAssets(buildAssets) {
    var chunkNames = Object.keys(buildAssets).filter(function (chunkName) {
        if (chunkName === 'main' || chunkName === 'manifest') {
            return false;
        }
        var chunk = buildAssets[chunkName];
        return !!chunk.js;
    });
    return tslib_1.__spreadArrays(['manifest'], chunkNames, ['main']).filter(function (chunkName) { return buildAssets[chunkName]; })
        .reduce(function (acc, chunkName) {
        // Turns out, webpack types are wrong, can be an array
        var jsAsset = buildAssets[chunkName].js;
        if (Array.isArray(jsAsset)) {
            acc.push.apply(acc, jsAsset.map(function (file) { return ({
                tag: "<script src=\"" + file + "\"></script>",
            }); }));
        }
        else {
            acc.push({
                tag: "<script src=\"" + buildAssets[chunkName].js + "\"></script>",
            });
        }
        return acc;
    }, []);
}
exports.getBodyAssets = getBodyAssets;
//# sourceMappingURL=assets.js.map