"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var server_1 = require("react-dom/server");
var url_1 = tslib_1.__importDefault(require("url"));
var config_1 = require("../../config/config");
var promise_tracker_1 = require("../../util/promise-tracker");
var assets_1 = require("../assets");
var ensure_request_log_middleware_1 = require("../middleware/ensure-request-log-middleware");
var _1 = require("./");
exports.createSsrMiddleware = function (options) {
    var runtimeConfig = config_1.getRuntimeConfig(options.app.log);
    var buildAssets = assets_1.getAssetLocations(runtimeConfig);
    return function (req, response, next) { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var promiseTracker, appState, renderContext, ssrOptions, pageRenderResult, createPageMarkup;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    if (!ensure_request_log_middleware_1.hasLog(req)) {
                        // eslint-disable-next-line no-console
                        console.error('Skipping SSR middleware due to missing req.log key');
                        return [2 /*return*/, next()];
                    }
                    promiseTracker = new promise_tracker_1.PromiseTracker();
                    return [4 /*yield*/, options.setupRequest(req, promiseTracker)];
                case 1:
                    appState = _a.sent();
                    ssrOptions = {
                        appRender: function () {
                            renderContext = {
                                promiseTracker: promiseTracker,
                                ssrRequestProps: appState,
                            };
                            return options.renderApp({
                                context: renderContext,
                                log: req.log,
                                req: req,
                            });
                        },
                        errorLocation: options.errorLocation,
                        events: {
                            // eslint-disable-next-line @typescript-eslint/no-empty-function
                            renderPerformed: function () { },
                        },
                        log: req.log,
                        pageNotFoundLocation: options.pageNotFoundLocation,
                        // Not perfect typings, if someone specifies the render result type
                        // as something it isn't, that's their own fault
                        renderFn: options.renderFn || server_1.renderToString,
                        resetRequest: function (location) { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
                            return tslib_1.__generator(this, function (_a) {
                                switch (_a.label) {
                                    case 0:
                                        req.url = location;
                                        req.query = url_1.default.parse(req.url, true).query;
                                        return [4 /*yield*/, options.setupRequest(req, promiseTracker)];
                                    case 1:
                                        appState = _a.sent();
                                        return [2 /*return*/];
                                }
                            });
                        }); },
                        ssrTimeoutMs: options.ssrTimeoutMs,
                    };
                    return [4 /*yield*/, _1.renderPageContents(appState, ssrOptions, req.url, promiseTracker)];
                case 2:
                    pageRenderResult = _a.sent();
                    createPageMarkup = function (result) {
                        var helmetTags = [];
                        if (result.head && result.head.title) {
                            helmetTags.push(result.head.title.toString());
                        }
                        if (result.head && result.head.base) {
                            helmetTags.push(result.head.base.toString());
                        }
                        if (result.head && result.head.script) {
                            helmetTags.push(result.head.script.toString());
                        }
                        if (result.head && result.head.meta) {
                            helmetTags.push(result.head.meta.toString());
                        }
                        if (result.head && result.head.link) {
                            helmetTags.push(result.head.link.toString());
                        }
                        var stateTransfers = [];
                        // When watchtower renders an error, the client needs to know
                        // so it can hydrate the error location. The WatchtowerBrowserRouter takes
                        // care of this
                        if (result.renderLocation !== req.originalUrl) {
                            stateTransfers.push({
                                tag: _1.transferState('watchtower_hydrate_location', result.renderLocation),
                            });
                        }
                        var pageTags = options.createPageTags
                            ? options.createPageTags({ buildAssets: buildAssets, helmetTags: helmetTags, stateTransfers: stateTransfers, renderContext: renderContext })
                            : {
                                body: tslib_1.__spreadArrays(assets_1.getBodyAssets(buildAssets)),
                                preBody: [],
                                head: tslib_1.__spreadArrays(helmetTags.map(function (tag) { return ({ tag: tag }); }), assets_1.getHeadAssets(buildAssets), stateTransfers),
                            };
                        return options.renderHtml({
                            context: renderContext,
                            head: result.head,
                            pageTags: pageTags,
                            renderResult: result.renderedContent,
                            req: req,
                        });
                    };
                    switch (pageRenderResult.type) {
                        case _1.ServerRenderResultType.Success:
                            response
                                .status(pageRenderResult.statusCode)
                                .header('Content-Type', 'text/html')
                                .send(createPageMarkup(pageRenderResult));
                            return [2 /*return*/];
                        case _1.ServerRenderResultType.Redirect:
                            response.redirect(pageRenderResult.isPermanent ? 301 : 302, pageRenderResult.redirectTo);
                            return [2 /*return*/];
                        case _1.ServerRenderResultType.Failure:
                        default:
                            // tslint:disable-line:no-switch-case-fall-through
                            response.status(500).send();
                    }
                    return [2 /*return*/];
            }
        });
    }); };
};
//# sourceMappingURL=create-middleware.js.map