"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var util_1 = tslib_1.__importDefault(require("util"));
exports.formatElapsed = function (hrEnd) {
    return util_1.default.format('%ds %dms', hrEnd[0], hrEnd[1] / 1000000);
};
exports.functionTimer = function (description, func, logger, logResult, 
/** Adds a category to the log object */
category) {
    var startTime = process.hrtime();
    try {
        var result = func();
        var elapsed = process.hrtime(startTime);
        var elapsedTime = exports.formatElapsed(elapsed);
        var logObj = {
            description: description,
            elapsed: elapsed,
        };
        if (logResult) {
            logObj.result = logResult(result);
        }
        if (category) {
            logObj.category = category;
        }
        logger.debug(logObj, description + " took " + elapsedTime);
        return result;
    }
    catch (err) {
        var elapsed = process.hrtime(startTime);
        var elapsedTime = exports.formatElapsed(elapsed);
        var logObj = {
            description: description,
            elapsed: elapsed,
            err: err,
        };
        if (category) {
            logObj.category = category;
        }
        logger.debug(logObj, description + " threw after " + elapsedTime);
        throw err;
    }
};
exports.functionTimerAsync = function (description, func, logger, logResult, 
/** Adds a category to the log object */
category) { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
    var startTime, result, elapsed, elapsedTime, logObj, err_1, elapsed, elapsedTime, logObj;
    return tslib_1.__generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                startTime = process.hrtime();
                _a.label = 1;
            case 1:
                _a.trys.push([1, 3, , 4]);
                return [4 /*yield*/, func()];
            case 2:
                result = _a.sent();
                elapsed = process.hrtime(startTime);
                elapsedTime = exports.formatElapsed(elapsed);
                logObj = {
                    description: description,
                    elapsed: elapsed,
                };
                if (logResult) {
                    logObj.result = logResult(result);
                }
                if (category) {
                    logObj.category = category;
                }
                logger.debug(logObj, "Async " + description + " took " + elapsedTime);
                return [2 /*return*/, result];
            case 3:
                err_1 = _a.sent();
                elapsed = process.hrtime(startTime);
                elapsedTime = exports.formatElapsed(elapsed);
                logObj = { description: description, elapsed: elapsed, err: err_1 };
                if (category) {
                    logObj.category = category;
                }
                logger.debug(logObj, "Async " + description + " threw after " + elapsedTime);
                throw err_1;
            case 4: return [2 /*return*/];
        }
    });
}); };
//# sourceMappingURL=function-timer.js.map