import fs from 'fs';
import path from 'path';
import TsconfigPathsPlugin from 'tsconfig-paths-webpack-plugin';
const disableCaching = String(process.env.BUILD_CACHE_DISABLED).toLowerCase() === 'true';
const disableTypeCheck = process.env.DISABLE_TYPE_CHECKING === 'true';
const cacheLoader = (cacheDirectory) => {
    return {
        loader: 'cache-loader',
        options: {
            cacheDirectory,
        },
    };
};
export function getTypeScriptWebpackRule(_plugins, resolvePlugins, options, buildTarget) {
    const configFile = (buildTarget === 'server'
        ? options.buildConfig.TS_CONFIG_SERVER
        : options.buildConfig.TS_CONFIG_CLIENT) || 'tsconfig.json';
    options.log.info(`Target ${buildTarget} using ts config file: ${configFile}`);
    const tsConfigPathsPluginConfig = {};
    const tsLoaderOptions = {
        compilerOptions: {
            noEmit: false,
        },
        transpileOnly: disableTypeCheck,
        experimentalWatchApi: true,
        projectReferences: true,
    };
    if (configFile) {
        tsConfigPathsPluginConfig.configFile = configFile;
        tsLoaderOptions.configFile = configFile;
    }
    resolvePlugins.push(new TsconfigPathsPlugin(tsConfigPathsPluginConfig));
    const babelConfigFile = (buildTarget === 'server'
        ? options.buildConfig.BABEL_CONFIG_SERVER
        : options.buildConfig.BABEL_CONFIG_CLIENT) || '.babelrc';
    let babelConfig = fs.existsSync(babelConfigFile)
        ? babelConfigFile
        : path.resolve(options.buildConfig.BASE, babelConfigFile);
    if (!fs.existsSync(babelConfig)) {
        babelConfig = path.resolve(process.cwd(), babelConfigFile);
        if (!fs.existsSync(babelConfig)) {
            babelConfig = undefined;
        }
    }
    if (babelConfig) {
        options.log.info(`Using babel config: ${babelConfig}`);
    }
    const tsLoader = {
        loader: 'ts-loader',
        options: tsLoaderOptions,
    };
    const babelLoader = {
        loader: 'babel-loader',
        options: {
            extends: babelConfig,
        },
    };
    return {
        test: /\.tsx?$/,
        use: !disableCaching
            ? [cacheLoader(options.cacheDirectory), babelLoader, tsLoader]
            : [babelLoader, tsLoader],
    };
}
//# sourceMappingURL=ts-loader-config.js.map