import fs from 'fs';
import path from 'path';
let assets;
let assetsLoaded = false;
export const getAssetsFile = (base) => path.resolve(base, 'assets.json');
const ensureAssets = (runtimeConfig) => {
    if (assetsLoaded) {
        return;
    }
    const assetsFile = getAssetsFile(runtimeConfig.BASE);
    try {
        const assetsFileContents = fs.readFileSync(assetsFile);
        assets = JSON.parse(assetsFileContents.toString());
        assetsLoaded = true;
    }
    catch (e) {
        throw new Error(`Cannot read assets file from ${assetsFile}`);
    }
};
export const setDefaultAssets = (buildConfig) => {
    // When running in dev mode, we don't use assets.json so we need to prime
    // the assets location
    updateAssetLocations({
        main: {
            css: buildConfig.PUBLIC_PATH + buildConfig.ASSETS_PATH_PREFIX + 'css/main.css',
            js: buildConfig.PUBLIC_PATH + buildConfig.ASSETS_PATH_PREFIX + 'js/main.js',
        },
    });
};
export function updateAssetLocations(newAssets) {
    assets = newAssets;
    assetsLoaded = true;
}
export function getAssetLocations(runtimeConfig) {
    ensureAssets(runtimeConfig);
    return assets;
}
export function getAssets(runtimeConfig) {
    ensureAssets(runtimeConfig);
    return assets;
}
export const getAbsoluteAssetPath = (runtimeConfig, asset) => {
    const staticPath = runtimeConfig.PUBLIC_PATH + runtimeConfig.ASSETS_PATH_PREFIX;
    let relativeAsset = asset.slice(staticPath.length);
    if (relativeAsset[0] === '/') {
        relativeAsset = relativeAsset.slice(1);
    }
    return path.resolve(runtimeConfig.ASSETS_PATH, relativeAsset);
};
export function getHeadAssets(buildAssets) {
    return Object.keys(buildAssets)
        .filter(chunkName => {
        const chunk = buildAssets[chunkName];
        return chunk.css;
    })
        .map(chunkName => ({
        tag: `<link id="css-main" type="text/css" rel="stylesheet" href="${buildAssets[chunkName].css}">`,
    }));
}
export function getBodyAssets(buildAssets) {
    const chunkNames = Object.keys(buildAssets).filter(chunkName => {
        if (chunkName === 'main' || chunkName === 'manifest') {
            return false;
        }
        const chunk = buildAssets[chunkName];
        return !!chunk.js;
    });
    return ['manifest', ...chunkNames, 'main']
        .filter(chunkName => buildAssets[chunkName])
        .reduce((acc, chunkName) => {
        // Turns out, webpack types are wrong, can be an array
        const jsAsset = buildAssets[chunkName].js;
        if (Array.isArray(jsAsset)) {
            acc.push(...jsAsset.map(file => ({
                tag: `<script src="${file}"></script>`,
            })));
        }
        else {
            acc.push({
                tag: `<script src="${buildAssets[chunkName].js}"></script>`,
            });
        }
        return acc;
    }, []);
}
//# sourceMappingURL=assets.js.map