import fs from 'fs';
import path from 'path';
import { getAssets, getBodyAssets, getHeadAssets } from '../assets';
import { PromiseTracker } from '../ssr/full-render';
import { renderHtml } from '../ssr/helpers/render-html';
const isProduction = process.env.NODE_ENV === 'production';
export const expressNoop = (_res, _req, next) => next();
export const getDefaultHtmlMiddleware = (log, runtimeConfig) => {
    // on production we just serve the generated index.html
    if (isProduction) {
        const indexPath = path.resolve(runtimeConfig.BASE, 'index.html');
        const indexFileMissing = !fs.existsSync(indexPath);
        let loggedMissingIndexFileError = false;
        const productionMiddleware = (_req, res) => {
            // We only log the error if we hit this middleware
            // if the consumer has registered their own SSR middleware we will
            // never use this, so no need to log an error
            if (indexFileMissing) {
                if (!loggedMissingIndexFileError) {
                    log.error('Cannot find index.html file to serve, default watchtower middleware will return 404');
                    loggedMissingIndexFileError = true;
                }
                return res.status(404);
            }
            return res.status(200).sendFile(indexPath);
        };
        return productionMiddleware;
    }
    // for development we grab the source index.html and add the assets
    let indexContent;
    if (runtimeConfig.SERVER_PUBLIC_DIR) {
        const indexPath = path.resolve(runtimeConfig.SERVER_PUBLIC_DIR, 'index.html');
        if (fs.existsSync(indexPath)) {
            indexContent = fs.readFileSync(indexPath, 'utf8');
        }
    }
    const middleware = (req, res) => {
        const buildAssets = getAssets(runtimeConfig);
        if (indexContent) {
            const withHeadTags = indexContent.replace('</head>', `${getHeadAssets(buildAssets)
                .map(headAsset => headAsset.tag)
                .join('\n')}
    </head>`);
            const withBodyTags = withHeadTags.replace('</body>', `${getBodyAssets(buildAssets)
                .map(bodyAsset => bodyAsset.tag)
                .join('\n')}
    </body>`);
            return res
                .status(200)
                .contentType('text/html')
                .send(withBodyTags);
        }
        const indexWithAssets = renderHtml({
            context: {
                promiseTracker: new PromiseTracker(),
                ssrRequestProps: {},
            },
            head: undefined,
            pageTags: {
                body: getBodyAssets(buildAssets),
                preBody: [],
                head: getHeadAssets(buildAssets),
            },
            renderResult: '',
            req,
        });
        return res
            .status(200)
            .contentType('text/html')
            .send(indexWithAssets);
    };
    return middleware;
};
//# sourceMappingURL=default-html-middleware.js.map