import webpack from 'webpack';
export const webpackStatsConfig = {
    children: false,
    chunkModules: false,
    chunks: false,
    colors: true,
    errors: true,
    timings: true,
    warnings: true,
    /* filter export warnings when transpileOnly:true -> https://github.com/TypeStrong/ts-loader/issues/751 */
    warningsFilter: /export .* was not found in/,
};
export const printWebpackStats = (log, stats) => {
    const statsString = stats.toString(webpackStatsConfig);
    log.info(statsString);
};
export const webpackPromise = (log, config) => new Promise((resolve, reject) => {
    webpack(config).run((err, stats) => {
        if (err) {
            log.error({ err }, 'Failed to compile');
            reject(err);
        }
        else {
            printWebpackStats(log, stats);
            if (stats.hasErrors()) {
                reject();
            }
            else {
                resolve();
            }
        }
    });
});
//# sourceMappingURL=webpack.js.map