import { __spreadArrays } from "tslib";
import build from './build';
import clean from './clean';
import exploreBundle from './explore-bundle';
import start from './start';
import watch from './watch';
import { getConfig } from '../runtime/config/config';
import { cliLogger } from '../util/log';
var args = process.argv.slice(2);
var command = args[0];
var commandArgs = args.slice(1);
var exitOnError = function (result) {
    result.catch(function (e) {
        cliLogger.error({ err: e }, 'Error occurred, exiting...');
        process.exit(1);
    });
};
var exitAfter = function (result) {
    return exitOnError(result.then(function () {
        // force process to exit
        process.exit(0);
    }));
};
var projectSwitchIndex = commandArgs.indexOf('-p');
var workingDirectory = process.cwd();
if (projectSwitchIndex !== -1) {
    var projectSwitchArgs = commandArgs.splice(projectSwitchIndex, 2);
    if (projectSwitchArgs.length === 2) {
        workingDirectory = projectSwitchArgs[1];
    }
}
var buildConfig = getConfig(cliLogger, workingDirectory);
switch (command) {
    case 'build':
        exitAfter(build.apply(void 0, __spreadArrays([cliLogger, buildConfig], commandArgs)));
        break;
    case 'clean':
        exitAfter(clean.apply(void 0, __spreadArrays([cliLogger, buildConfig], commandArgs)));
        break;
    case 'explore-bundle':
        exitOnError(exploreBundle.apply(void 0, __spreadArrays([cliLogger, buildConfig], commandArgs)));
        break;
    case 'start':
        exitOnError(start.apply(void 0, __spreadArrays([cliLogger, buildConfig, {}], commandArgs)));
        break;
    case 'watch':
        exitOnError(watch.apply(void 0, __spreadArrays([cliLogger, buildConfig, {}], commandArgs)));
        break;
    default:
        cliLogger.info("\n## Project Watchtower\n\nScripts:\n\n    build [<target>] [<environment>] [-p <project dir>]\n    clean [-p <project dir>] [<glob> ...]\n    explore-bundle [disableHoisting] [-p <project dir>]\n    start [watch] [prod] [debug] [client] [-p <project dir>]\n    watch [server] [client] [debug] [-p <project dir>]\n\nRefer to docs/cli.md for the full API documentation\n");
}
//# sourceMappingURL=index.js.map