import { __assign } from "tslib";
import dotenv from 'dotenv';
import path from 'path';
import { forkPromise } from '../util/process';
/**
 * Starts the pre-built server with the environment variables
 * defined in `.env`
 * @param args
 * - watch: Enables watch mode
 * - prod: Sets NODE_ENV to "production"
 * - debug: Starts with debugging enabled
 * - debug-brk: Starts with debugging and waits for debugger to attach
 * - --debug-port <port>: The port to debug on
 */
var start = function (log, buildConfig, startEnv) {
    var args = [];
    for (var _i = 3; _i < arguments.length; _i++) {
        args[_i - 3] = arguments[_i];
    }
    // When running in local dev, we have a different process.cwd() than
    // when running in production. This allows static files and such to resolve
    var HAS_SERVER = buildConfig.HAS_SERVER, OUTPUT = buildConfig.OUTPUT;
    var env = __assign(__assign({}, startEnv), { NODE_ENV: args.indexOf('prod') !== -1 ? 'production' : process.env.NODE_ENV || 'development', PORT: buildConfig.DEV_SERVER_PORT.toString(), PROJECT_DIR: buildConfig.BASE });
    if (args.indexOf('watch') !== -1) {
        env.START_WATCH_MODE = 'true';
    }
    var isDebug = args.indexOf('debug') !== -1;
    var isDebugBrk = args.indexOf('debug-brk') !== -1;
    var debugPort = 5858;
    if (isDebug || isDebugBrk) {
        env.START_DEBUG_MODE = 'true';
    }
    var portIndex = args.indexOf('--debug-port');
    if (portIndex !== -1) {
        debugPort = Number(args[portIndex + 1]);
        args.slice(portIndex, 2);
    }
    var clientMode = !HAS_SERVER || args.indexOf('client') !== -1;
    var serverPath = clientMode
        ? path.resolve(process.env.TEST_BIN_DIR || __dirname, '..', 'server', 'start.js')
        : path.resolve(OUTPUT, 'server.js');
    dotenv.config({
        path: path.join(buildConfig.BASE, '.env'),
    });
    var execArgv = process.execArgv.filter(function (arg) { return arg.indexOf('--inspect') !== 0; });
    if (isDebug) {
        execArgv.push("--inspect=" + debugPort);
    }
    if (isDebugBrk) {
        execArgv.push("--inspect-brk=" + debugPort);
    }
    var options = {
        env: __assign(__assign({}, process.env), env),
        execArgv: execArgv,
    };
    return forkPromise(log, serverPath, [], options, true);
};
export default start;
//# sourceMappingURL=start.js.map