import fs from 'fs';
import path from 'path';
import TsconfigPathsPlugin from 'tsconfig-paths-webpack-plugin';
var disableCaching = String(process.env.BUILD_CACHE_DISABLED).toLowerCase() === 'true';
var disableTypeCheck = process.env.DISABLE_TYPE_CHECKING === 'true';
var cacheLoader = function (cacheDirectory) {
    return {
        loader: 'cache-loader',
        options: {
            cacheDirectory: cacheDirectory,
        },
    };
};
export function getTypeScriptWebpackRule(_plugins, resolvePlugins, options, buildTarget) {
    var configFile = (buildTarget === 'server'
        ? options.buildConfig.TS_CONFIG_SERVER
        : options.buildConfig.TS_CONFIG_CLIENT) || 'tsconfig.json';
    options.log.info("Target " + buildTarget + " using ts config file: " + configFile);
    var tsConfigPathsPluginConfig = {};
    var tsLoaderOptions = {
        compilerOptions: {
            noEmit: false,
        },
        transpileOnly: disableTypeCheck,
        experimentalWatchApi: true,
        projectReferences: true,
    };
    if (configFile) {
        tsConfigPathsPluginConfig.configFile = configFile;
        tsLoaderOptions.configFile = configFile;
    }
    resolvePlugins.push(new TsconfigPathsPlugin(tsConfigPathsPluginConfig));
    var babelConfigFile = (buildTarget === 'server'
        ? options.buildConfig.BABEL_CONFIG_SERVER
        : options.buildConfig.BABEL_CONFIG_CLIENT) || '.babelrc';
    var babelConfig = fs.existsSync(babelConfigFile)
        ? babelConfigFile
        : path.resolve(options.buildConfig.BASE, babelConfigFile);
    if (!fs.existsSync(babelConfig)) {
        babelConfig = path.resolve(process.cwd(), babelConfigFile);
        if (!fs.existsSync(babelConfig)) {
            babelConfig = undefined;
        }
    }
    if (babelConfig) {
        options.log.info("Using babel config: " + babelConfig);
    }
    var tsLoader = {
        loader: 'ts-loader',
        options: tsLoaderOptions,
    };
    var babelLoader = {
        loader: 'babel-loader',
        options: {
            extends: babelConfig,
        },
    };
    return {
        test: /\.tsx?$/,
        use: !disableCaching
            ? [cacheLoader(options.cacheDirectory), babelLoader, tsLoader]
            : [babelLoader, tsLoader],
    };
}
//# sourceMappingURL=ts-loader-config.js.map