import { consoleLogger } from 'typescript-log';
import { PromiseTracker } from '../../../universal';
import { recursiveTaskResolver } from './recursive-task-resolver';
var testLogger = consoleLogger();
describe('Recursive Task Resolver', function () {
    it('Should abort after 5 tries', function (done) {
        var promiseTracker = new PromiseTracker();
        var count = 0;
        var render = function () {
            if (count++ > 5) {
                done(new Error('Too many render calls!'));
            }
            promiseTracker.track(new Promise(function (resolve) { return setTimeout(resolve, 10); }));
            return '';
        };
        render();
        recursiveTaskResolver(testLogger, promiseTracker, render, '/', '', 5 /* attempts */, 500 /* ms */)
            .then(function () { return done(new Error('Expected too many recurses error')); }, function (err) {
            return expect(err.message).toEqual('Abort waiting for loading all data after 5 recursive waits');
        })
            .then(function () { return done(); })
            .catch(done);
    });
    it('Resolves when nested promise resolves', function (done) {
        var promiseTracker = new PromiseTracker();
        var count = 0;
        var resolvedSecondPromise = false;
        var render = function () {
            if (count === 0) {
                promiseTracker.track(new Promise(function (resolve) { return setTimeout(resolve, 10); }));
            }
            else if (count === 1) {
                var secondPromise = new Promise(function (resolve) { return setTimeout(resolve, 10); }).then(function () {
                    resolvedSecondPromise = true;
                });
                promiseTracker.track(secondPromise);
            }
            count++;
            return '';
        };
        render();
        recursiveTaskResolver(testLogger, promiseTracker, render, '/', '', 5, // attempts
        100)
            .then(function () {
            expect(resolvedSecondPromise).toBe(true);
            done();
        })
            .catch(done);
    });
});
//# sourceMappingURL=recursive-task-resolver.spec.js.map