/* eslint-disable @typescript-eslint/camelcase */
/* eslint-disable no-var */
import fs from 'fs';
import path from 'path';
export var readFileSync = function (log, filePath) {
    try {
        return fs.readFileSync(filePath, 'utf8');
    }
    catch (err) {
        log.error({ err: err, filePath: filePath }, 'Error reading file');
        throw err;
    }
};
export var readFile = function (log, filePath) {
    return new Promise(function (resolve, reject) {
        fs.readFile(filePath, 'utf8', function (err, data) {
            if (err) {
                log.error({ err: err, filePath: filePath }, 'Error reading file');
                reject(err);
            }
            else {
                resolve(data);
            }
        });
    });
};
export var getFileSize = function (log, filePath) {
    return new Promise(function (resolve, reject) {
        fs.stat(filePath, function (err, stats) {
            if (err) {
                log.error({ err: err, filePath: filePath }, 'Error getting file size');
                reject(err);
            }
            else {
                resolve(stats.size);
            }
        });
    });
};
export var writeFile = function (log, filePath, fileContent) {
    return new Promise(function (resolve, reject) {
        fs.writeFile(filePath, fileContent, function (err) {
            if (err) {
                log.error({ err: err, filePath: filePath }, 'Error writing file');
                reject(err);
            }
            else {
                resolve();
            }
        });
    });
};
export var formatFileSize = function (size) { return (size / 1024).toFixed(4); };
export var existsSync = function (file) {
    try {
        fs.accessSync(file);
        return true;
    }
    catch (ex) {
        return false;
    }
};
/**
 * Dynamically require a file in a way that works both in node and from a webpack bundle
 */
export var dynamicRequire = function (file) {
    if (typeof __non_webpack_require__ !== 'undefined') {
        return __non_webpack_require__(file);
    }
    else {
        // apparently just wrapping require() in a function is enough
        // to make webpack not try and bundle complete directories.
        // without the presence of above __non_webpack_require__ it would however emit a warning
        // "Critical dependency: the request of a dependency is an expression"
        // Need to eval otherwise we get the above warning
        return eval('module.require')(file);
    }
};
/**
 * Get custon config file if it exists as JavaScript
 * Abort with an error if it only exists as TypeScript
 * @param filePath File path from project root (without extension)
 */
export var getCustomConfigFile = function (log, root, filePath, fallback) {
    var customConfigFile = path.resolve(root, filePath + '.js');
    var customConfigFileTS = path.resolve(root, filePath + '.ts');
    if (existsSync(customConfigFile)) {
        // using dynamicRequire to support bundling project-watchtower with webpack
        var config = dynamicRequire(customConfigFile).default;
        if (typeof config === 'function') {
            return config(root);
        }
        return config;
    }
    // We don't dynamically compile because that would add more runtime
    // dependencies to watchtower.
    if (existsSync(customConfigFileTS)) {
        log.error(filePath + ' only found as TypeScript file.');
        log.error('Please make sure to compile all TS files in the /config folder to JS!');
        process.exit(1);
    }
    return fallback;
};
//# sourceMappingURL=fs.js.map